@@ -14,7 +14,14 @@ Examples:
         >>> from ufjc.potential import LennardJonesPotential
         >>> model = LennardJonesPotential(varepsilon=8)
         >>> model.beta_u(1.23)
-        -3.953345685631384
+        4.046654314368616
+
+    Do the same with the Lenard-Jones-FENE potential:
+
+        >>> from ufjc.potential import LJFENEPotential
+        >>> model = LJFENEPotential(varepsilon=(8, 8))
+        >>> model.beta_u(1.23)
+        8.510502022381505
 
     Create a single-link model in one dimension, instantiate it with
     the Morse potential, and compute the incremental link stretch under
@@ -24,8 +31,9 @@ Examples:
         >>> class Link1D(Potential):
         ...     def __init__(self, **kwargs):
         ...         Potential.__init__(self, **kwargs)
-        >>> Link1D(potential='morse').delta_lambda(8)
-        0.04890980361596759
+        >>> _ = Link1D(potential='morse').delta_lambda(8)
+        >>> Link1D(potential='lj-fene').eta_link(1)
+        184.0
 
 """
 
@@ -310,8 +318,7 @@ class MorsePotential(object):
             Compute the nondimensional force at a sample stretch:
 
                 >>> from ufjc.potential import MorsePotential
-                >>> MorsePotential().eta_link(1.23)
-                28.731992431367807
+                >>> _ = MorsePotential().eta_link(1.23)
 
         """
         return 2*self.alpha*self.varepsilon * \
@@ -335,7 +342,9 @@ class MorsePotential(object):
             numpy.ndarray: The incremental stretch(s).
 
         """
-        return np.log(2/(1 + np.sqrt(1 - eta/self.eta_max)))/self.alpha
+        return np.log(
+            2/(1 + np.sqrt(1 - eta/self.eta_max))
+        )/self.alpha
 
 
 class LennardJonesPotential(object):
@@ -372,7 +381,7 @@ class LennardJonesPotential(object):
 
             .. math::
                 \phi(\lambda) =
-                    \frac{1}{\lambda^{12}} - \frac{2}{\lambda^6}
+                    \frac{1}{\lambda^{12}} - \frac{2}{\lambda^6} + 1
                 .
 
         Args:
@@ -382,7 +391,7 @@ class LennardJonesPotential(object):
             numpy.ndarray: The scaled nondimensional potential energy(s).
 
         """
-        return 1/lambda_**12 - 2/lambda_**6
+        return 1/lambda_**12 - 2/lambda_**6 + 1
 
     def beta_u(self, lambda_):
         r"""The nondimensional potential energy function,
@@ -418,6 +427,111 @@ class LennardJonesPotential(object):
         return self.varepsilon*(12/lambda_**7 - 12/lambda_**13)
 
 
+class LJFENEPotential(object):
+    r"""The Lennard-Jones-FENE potential :cite:`kremer1990dynamics`.
+
+    Attributes:
+        varepsilon (float): The nondimensional energy scale.
+        kappa (float): The nondimensional stiffness.
+        c (float): The correction parameter.
+        eta_max (float): The maximum nondimensional force
+            :math:`\eta_\mathrm{max} = \eta(\lambda_\mathrm{max})`.
+        lambda_max (float): The stretch at the maximum nondimensional force.
+
+    """
+    def __init__(self, **kwargs):
+        """Initializes the ``LJFENEPotential`` class.
+
+        Args:
+            **kwargs: Arbitrary keyword arguments.
+                Can be used to specify ``varepsilon`` (default (88, 230))
+                and ``lambda_max`` (default 1.5).
+
+        """
+        self.varepsilon_1, self.varepsilon_2 = \
+            kwargs.get('varepsilon', (88, 230))
+        self.varepsilon = self.varepsilon_2
+        self.lambda_max = kwargs.get('lambda_max', 1.5)
+        self.kappa = 72*self.varepsilon_1 + self.varepsilon_2 * \
+            (self.lambda_max**2 + 1)/(self.lambda_max**2 - 1)**2
+        self.c = 1/(1 - (
+                -1512 + (6*self.lambda_max**2 + 2)/(self.lambda_max**2 - 1)**3
+            )/(2*self.kappa/self.varepsilon_2)
+        )
+        self.eta_max = self.eta_link(self.lambda_max)
+
+    def phi(self, lambda_):
+        r"""The scaled nondimensional potential energy function,
+
+            .. math::
+                \phi(\lambda) =
+                \frac{\varepsilon_1}{\varepsilon_2}\left(
+                    \frac{1}{\lambda^{12}} - \frac{2}{\lambda^6} + 1
+                \right) - \frac{1}{2}\,\ln\left[
+                    1 - \left(\frac{\lambda}{\lambda_\mathrm{max}}\right)^2
+                \right]
+                .
+
+        Args:
+            lambda_ (array_like): The stretch(s).
+
+        Returns:
+            numpy.ndarray: The scaled nondimensional potential energy(s).
+
+        """
+        lambda_fene = (lambda_ < self.lambda_max)*lambda_
+        return self.varepsilon_1/self.varepsilon_2*(
+            1/lambda_**12 - 2/lambda_**6 + 1
+        ) - 0.5*np.log(
+            1 - (lambda_fene/self.lambda_max)**2
+        )*(lambda_ < self.lambda_max)
+
+    def beta_u(self, lambda_):
+        r"""The nondimensional potential energy function,
+
+            .. math::
+                \beta u(\lambda) =
+                \varepsilon\phi(\lambda) =
+                \varepsilon_1\left(
+                    \frac{1}{\lambda^{12}} - \frac{2}{\lambda^6} + 1
+                \right) - \frac{\varepsilon_2}{2}\,\ln\left[
+                    1 - \left(\frac{\lambda}{\lambda_\mathrm{max}}\right)^2
+                \right]
+                .
+
+        Args:
+            lambda_ (array_like): The stretch(s).
+
+        Returns:
+            numpy.ndarray: The nondimensional potential energy(s).
+
+        """
+        return self.varepsilon*self.phi(lambda_)
+
+    def eta_link(self, lambda_):
+        r"""The nondimensional force as a function of stretch,
+
+            .. math::
+                \eta(\lambda) = 12\varepsilon_1\left(
+                    \frac{1}{\lambda^7} - \frac{1}{\lambda^{13}}
+                \right) + \frac{\varepsilon_2\lambda}
+                {\lambda_\mathrm{max}^2 - \lambda^2}
+                .
+
+        Args:
+            lambda_ (array_like): The stretch(s).
+
+        Returns:
+            numpy.ndarray: The nondimensional force(s).
+
+        """
+        lambda_fene = (lambda_ < self.lambda_max)*lambda_
+        return self.varepsilon_1*(12/lambda_**7 - 12/lambda_**13) + \
+            self.varepsilon_2*lambda_fene/(
+                self.lambda_max**2 - lambda_fene**2
+        )*(lambda_ < self.lambda_max)
+
+
 class MiePotential(object):
     r"""The Mie potential :cite:`mie1903kinetischen`.
 
@@ -449,10 +563,17 @@ class MiePotential(object):
         self.m = kwargs.get('m', 6)
         self.n = kwargs.get('n', 12)
         self.kappa = self.n*self.m*self.varepsilon
-        self.c = (4*self.m*(self.m + 1) - 2*self.n*(self.n + 1))/(
+        self.c = (
+            4*self.m*(self.m + 1) - 2*self.n*(self.n + 1)
+        )/(
             2*self.m*(self.m**2 + 5*self.m + 4) -
-            self.n*(self.n**2 + 5*self.n + 4))
-        self.lambda_max = ((self.n + 1)/(self.m + 1))**(1/(self.n - self.m))
+            self.n*(self.n**2 + 5*self.n + 4)
+        )
+        self.lambda_max = (
+            (self.n + 1)/(self.m + 1)
+        )**(
+            1/(self.n - self.m)
+        )
         self.eta_max = self.eta_link(self.lambda_max)
 
     def phi(self, lambda_):
@@ -470,8 +591,11 @@ class MiePotential(object):
             numpy.ndarray: The scaled nondimensional potential energy(s).
 
         """
-        return (self.m/lambda_**self.n -
-                self.n/lambda_**self.m)/(self.n - self.m)
+        return (
+            self.m/lambda_**self.n - self.n/lambda_**self.m
+        )/(
+            self.n - self.m
+        )
 
     def beta_u(self, lambda_):
         r"""The nondimensional potential energy function,
@@ -506,7 +630,8 @@ class MiePotential(object):
 
         """
         return self.varepsilon*self.n*self.m/(self.n - self.m)*(
-            1/lambda_**(self.m + 1) - 1/lambda_**(self.n + 1))
+            1/lambda_**(self.m + 1) - 1/lambda_**(self.n + 1)
+        )
 
 
 class PolynomialPotential(object):
@@ -533,8 +658,10 @@ class PolynomialPotential(object):
         self.varepsilon = kwargs.get('varepsilon', 88)
         coef = np.array(kwargs.get('coefficients', [1, 0]))
         self.eta_c = np.append(np.array([0]), coef)
-        self.phi_c = np.append([0], self.eta_c) * \
-            np.append([0, 0], [1/n for n in range(2, len(coef) + 2)])
+        self.phi_c = np.append([0], self.eta_c)*np.append(
+            [0, 0],
+            [1/n for n in range(2, len(coef) + 2)]
+        )
         self.kappa = self.varepsilon*self.eta_c[1]
         if len(self.phi_c) > 3:
             self.c = 1/(1 - self.phi_c[3]/self.phi_c[2]/2)
@@ -675,6 +802,8 @@ class Potential(object):
             self.pot = MorsePotential(**kwargs)
         elif self.potential == 'lennard-jones':
             self.pot = LennardJonesPotential(**kwargs)
+        elif self.potential == 'lj-fene':
+            self.pot = LJFENEPotential(**kwargs)
         elif self.potential == 'mie':
             self.pot = MiePotential(**kwargs)
         elif self.potential == 'polynomial':
